YARP 2.3.70.1 (2017-09-21)                                          {#v2_3_70_1}
==========================

[TOC]

YARP 2.3.70.1 Release Notes
===========================


A (partial) list of bug fixed and issues resolved in this release can be found
[here](https://github.com/robotology/yarp/issues?q=label%3A%22Fixed+in%3A+YARP+v2.3.70.1%22).


Bug Fixes
---------

### CMake Modules

* Full paths were never exported by `yarp_configure_external_installation`
  command. This has been fixed.

### Libraries

#### YARP_OS

* Fixed `Route::swapNames()` segfault in Windows and MacOS.
* Fixed mcast without ACE on macOS
* Fixed memory leak for inactive carriers
* Fixed mcast, the connection now continue working also if you disconnect
  the *first* mcast connection.
* Removed the inheritance from `SocketTwoWayStream` in `LocalCarrierStream`.
* Fixed setConnectionQos() for local carrier.
* Added `flush()` at the end of `AbstractCarrier::writeYarpInt()` to finalize
  the write.
* Fixed memory leak in port authentication.
* Fixed Buffer not null terminated in impl/SplitString.
* Added the check for spaces in the port names in `Network:metaConnect()`.

### YARP_dev
* IPWMControl and ICurrentControl interfaces are now correctly wrapped by the the `ControlBoardRemapper`.

#### YARP_manager

* Removed `using namespace` directive from headers.


### Devices

#### rplidar2

* Fixed build on MSVC

### GUIs

#### yarpview

* Fixed coordinates of clicked point when yarpview window is resized.
* Added Unix signal handler(SIGQUIT, SIGINT, SIGTERM, SIGHUP).


Contributors
------------

This is a list of people that contributed to this release (generated from the
git history using `git shortlog -ens --no-merges v2.3.70..v2.3.70.1`):

```
    31	Daniele E. Domenichelli <daniele.domenichelli@iit.it>
    21	Nicolò Genesio <nicolo.genesio@iit.it>
     3	Marco Randazzo <marco.randazzo@iit.it>
     2	Bartek Łukawski <bwmn.peter@gmail.com>
     1	Andrea Ruzzenenti <andrea.ruzzenenti@iit.it>
     1	Matteo Brunettini <matteo.brunettini@iit.it>
     1	Nuno Guedelha <nuno.guedelha@iit.it>
     1	Silvio Traversaro <silvio.traversaro@iit.it>
     1	Ugo Pattacini <ugo.pattacini@iit.it>
```
